@@ -27,7 +27,9 @@ __all__ = (
     "OutputDataConfigTypeDef",
     "ComprehendMedicalAsyncJobPropertiesTypeDef",
     "DescribeEntitiesDetectionV2JobResponseTypeDef",
+    "DescribeICD10CMInferenceJobResponseTypeDef",
     "DescribePHIDetectionJobResponseTypeDef",
+    "DescribeRxNormInferenceJobResponseTypeDef",
     "TraitTypeDef",
     "AttributeTypeDef",
     "EntityTypeDef",
@@ -46,11 +48,17 @@ __all__ = (
     "RxNormEntityTypeDef",
     "InferRxNormResponseTypeDef",
     "ListEntitiesDetectionV2JobsResponseTypeDef",
+    "ListICD10CMInferenceJobsResponseTypeDef",
     "ListPHIDetectionJobsResponseTypeDef",
+    "ListRxNormInferenceJobsResponseTypeDef",
     "StartEntitiesDetectionV2JobResponseTypeDef",
+    "StartICD10CMInferenceJobResponseTypeDef",
     "StartPHIDetectionJobResponseTypeDef",
+    "StartRxNormInferenceJobResponseTypeDef",
     "StopEntitiesDetectionV2JobResponseTypeDef",
+    "StopICD10CMInferenceJobResponseTypeDef",
     "StopPHIDetectionJobResponseTypeDef",
+    "StopRxNormInferenceJobResponseTypeDef",
 )
 
 ComprehendMedicalAsyncJobFilterTypeDef = TypedDict(
@@ -127,12 +135,24 @@ DescribeEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribeICD10CMInferenceJobResponseTypeDef = TypedDict(
+    "DescribeICD10CMInferenceJobResponseTypeDef",
+    {"ComprehendMedicalAsyncJobProperties": ComprehendMedicalAsyncJobPropertiesTypeDef},
+    total=False,
+)
+
 DescribePHIDetectionJobResponseTypeDef = TypedDict(
     "DescribePHIDetectionJobResponseTypeDef",
     {"ComprehendMedicalAsyncJobProperties": ComprehendMedicalAsyncJobPropertiesTypeDef},
     total=False,
 )
 
+DescribeRxNormInferenceJobResponseTypeDef = TypedDict(
+    "DescribeRxNormInferenceJobResponseTypeDef",
+    {"ComprehendMedicalAsyncJobProperties": ComprehendMedicalAsyncJobPropertiesTypeDef},
+    total=False,
+)
+
 TraitTypeDef = TypedDict(
     "TraitTypeDef",
     {"Name": Literal["SIGN", "SYMPTOM", "DIAGNOSIS", "NEGATION"], "Score": float},
@@ -462,6 +482,15 @@ ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListICD10CMInferenceJobsResponseTypeDef = TypedDict(
+    "ListICD10CMInferenceJobsResponseTypeDef",
+    {
+        "ComprehendMedicalAsyncJobPropertiesList": List[ComprehendMedicalAsyncJobPropertiesTypeDef],
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListPHIDetectionJobsResponseTypeDef = TypedDict(
     "ListPHIDetectionJobsResponseTypeDef",
     {
@@ -471,18 +500,43 @@ ListPHIDetectionJobsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListRxNormInferenceJobsResponseTypeDef = TypedDict(
+    "ListRxNormInferenceJobsResponseTypeDef",
+    {
+        "ComprehendMedicalAsyncJobPropertiesList": List[ComprehendMedicalAsyncJobPropertiesTypeDef],
+        "NextToken": str,
+    },
+    total=False,
+)
+
 StartEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     "StartEntitiesDetectionV2JobResponseTypeDef", {"JobId": str}, total=False
 )
 
+StartICD10CMInferenceJobResponseTypeDef = TypedDict(
+    "StartICD10CMInferenceJobResponseTypeDef", {"JobId": str}, total=False
+)
+
 StartPHIDetectionJobResponseTypeDef = TypedDict(
     "StartPHIDetectionJobResponseTypeDef", {"JobId": str}, total=False
 )
 
+StartRxNormInferenceJobResponseTypeDef = TypedDict(
+    "StartRxNormInferenceJobResponseTypeDef", {"JobId": str}, total=False
+)
+
 StopEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     "StopEntitiesDetectionV2JobResponseTypeDef", {"JobId": str}, total=False
 )
 
+StopICD10CMInferenceJobResponseTypeDef = TypedDict(
+    "StopICD10CMInferenceJobResponseTypeDef", {"JobId": str}, total=False
+)
+
 StopPHIDetectionJobResponseTypeDef = TypedDict(
     "StopPHIDetectionJobResponseTypeDef", {"JobId": str}, total=False
 )
+
+StopRxNormInferenceJobResponseTypeDef = TypedDict(
+    "StopRxNormInferenceJobResponseTypeDef", {"JobId": str}, total=False
+)
